Skip to Content.
Sympa Menu

en - [PATCH] "Authentificate" is not an English word....

Subject: The mailing list for listmasters using Sympa

List archive

Chronological Thread  
  • From: Chip Salzenberg <address@concealed>
  • To: address@concealed
  • Subject: [PATCH] "Authentificate" is not an English word....
  • Date: Mon, 29 May 2000 17:27:03 -0700

... though it's a reasonable guess for a French writer. :-)

I suggest the application of this patch to Commands.pm.

--- Commands.pm.distrib Wed May 24 13:47:54 2000
+++ Commands.pm Wed Apr 12 01:58:56 2000
@@ -401,5 +401,5 @@
do_log ('debug', 'auth should be %s',List::compute_auth
('','review',$listname ));
push @msg::report, sprintf Msg(6, 15, $msg::wrong_authenticator);
- do_log('info', 'REVIEW %s from %s refused because wrong
authentification', $listname,$sender);
+ do_log('info', 'REVIEW %s from %s refused for bad
authentication', $listname,$sender);
return 'wrong_auth';
}
@@ -413,5 +413,5 @@
do_log ('debug',"auth requested from $sender");
List::request_auth ($sender,'review',$listname);
- do_log('info', 'REVIEW %s from %s authentified (%d seconds)',
$listname, $sender,time-$time_command);
+ do_log('info', 'REVIEW %s from %s auth requested (%d seconds)',
$listname, $sender,time-$time_command);
return 1;
}
@@ -496,5 +496,5 @@
push @msg::report, sprintf Msg(6, 15, $msg::wrong_authenticator);
push @msg::report, sprintf Msg(6, 16, $msg::non_canonical);
- do_log('info', 'SUB %s from %s refused because wrong
authentification'
+ do_log('info', 'SUB %s from %s refused for bad authentication'
, $which,$sender);
return 'wrong_auth';
@@ -523,5 +523,5 @@
if ($action =~ /request_auth/i) {
List::request_auth ($sender,'sub',$which,$comment );
- do_log('info', 'SUB %s from %s authentified (%d seconds)', $which,
$sender,time-$time_command);
+ do_log('info', 'SUB %s from %s auth requested (%d seconds)', $which,
$sender,time-$time_command);
return 1;
}
@@ -606,5 +606,5 @@
do_log ('debug', 'auth should be %s',List::compute_auth
('','info',$listname ));
push @msg::report, sprintf Msg(6, 15, $msg::wrong_authenticator);
- do_log('info', 'INFO %s from %s refused because wrong
authentification', $listname,$sender);
+ do_log('info', 'INFO %s from %s refused for bad authentication',
$listname,$sender);
return 'wrong_auth';
}
@@ -631,5 +631,5 @@
do_log ('debug',"auth requested from $sender");
List::request_auth ($sender,'info',$listname);
- do_log('info', 'REVIEW %s from %s authentified (%d seconds)',
$listname, $sender,time-$time_command);
+ do_log('info', 'REVIEW %s from %s auth requested (%d seconds)',
$listname, $sender,time-$time_command);
return 1;
}
@@ -682,5 +682,5 @@
push @msg::report, sprintf Msg(6, 15, $msg::wrong_authenticator);
push @msg::report, sprintf Msg(6, 16, $msg::non_canonical);
- do_log('info', 'SIG %s from %s refused because wrong
authentification'
+ do_log('info', 'SIG %s from %s refused for bad authentication'
, $which,$sender);
return 'wrong_auth';
@@ -700,5 +700,5 @@
if ($action =~ /request_auth\s*\(\s*\[\s*(email|sender)\s*\]\s*\)/i) {
&List::request_auth ($$1,'signoff',$which );
- do_log('info', 'SIG %s from %s authentified (%d seconds)', $which,
$sender,time-$time_command);
+ do_log('info', 'SIG %s from %s auth requested (%d seconds)', $which,
$sender,time-$time_command);
return 1;
}
@@ -775,5 +775,5 @@
push @msg::report, sprintf Msg(6, 15, $msg::wrong_authenticator);
push @msg::report, sprintf Msg(6, 16, $msg::non_canonical);
- do_log('info', 'ADD %s %s from %s refused because wrong
authentification', $which,$email,$sender);
+ do_log('info', 'ADD %s %s from %s refused for bad
authentication', $which,$email,$sender);
return 'wrong_auth';
}
@@ -792,5 +792,5 @@
if ($action =~ /request_auth/i) {
List::request_auth ($sender, 'add', $which, $email, $comment);
- do_log('info', 'ADD %s from %s authentified (%d seconds)', $which,
$sender,time-$time_command);
+ do_log('info', 'ADD %s from %s auth requested (%d seconds)', $which,
$sender,time-$time_command);
return 1;
}
@@ -865,5 +865,5 @@
push @msg::report, sprintf Msg(6, 15, $msg::wrong_authenticator);
push @msg::report, sprintf Msg(6, 16, $msg::non_canonical);
- do_log('info', 'ADD %s %s from %s refused because wrong
authentification', $which,$email,$sender);
+ do_log('info', 'ADD %s %s from %s refused for bad
authentication', $which,$email,$sender);
return 'wrong_auth';
}
@@ -882,5 +882,5 @@
if ($action =~ /request_auth/i) {
List::request_auth ($sender, 'invite', $which, $email, $comment);
- do_log('info', 'INVITE %s from %s authentified (%d seconds)', $which,
$sender,time-$time_command);
+ do_log('info', 'INVITE %s from %s auth requested (%d seconds)',
$which, $sender,time-$time_command);
return 1;
}
@@ -955,5 +955,5 @@
do_log ('debug', 'auth should be %s',List::compute_auth
('','remind',$listname ));
push @msg::report, sprintf Msg(6, 15, $msg::wrong_authenticator);
- do_log('info', 'REMIND %s from %s refused because wrong
authentification', $listname,$sender);
+ do_log('info', 'REMIND %s from %s refused for bad
authentication', $listname,$sender);
return 'wrong_auth';
}
@@ -981,5 +981,5 @@
do_log ('debug',"auth requested from $sender");
List::request_auth ($sender,'remind',$listname);
- do_log('info', 'REMIND %s from %s authentified (%d seconds)',
$listname, $sender,time-$time_command);
+ do_log('info', 'REMIND %s from %s auth requested (%d seconds)',
$listname, $sender,time-$time_command);
return 1;
}elsif ($action =~ /do_it/i) {
@@ -1096,5 +1096,5 @@
push @msg::report, sprintf Msg(6, 15, $msg::wrong_authenticator);
push @msg::report, sprintf Msg(6, 16, $msg::non_canonical);
- do_log('info', 'DEL %s %s from %s refused because wrong
authentification'
+ do_log('info', 'DEL %s %s from %s refused for bad authentication'
, $which,$who,$sender);
return 'wrong_auth';
@@ -1115,5 +1115,5 @@
if ($action =~ /request_auth/i) {
List::request_auth ($sender,'del',$which,$who );
- do_log('info', 'DEL %s %s from %s authentified (%d seconds)', $which,
$who, $sender,time-$time_command);
+ do_log('info', 'DEL %s %s from %s auth requested (%d seconds)',
$which, $who, $sender,time-$time_command);
return 1;
}
@@ -1694,5 +1694,5 @@
if (! open(IN, "$queueexpire\/\.$name\_$auth")) {
push @msg::report, sprintf Msg(6, 15,
$msg::wrong_authenticator);
- do_log('info', 'EXPIRE %s %d %d from %s refused because wrong
authentification', $name,
+ do_log('info', 'EXPIRE %s %d %d from %s refused for bad
authentication', $name,
$limitday,$confirmday,$sender);
return 'wrong_auth';
@@ -1752,5 +1752,5 @@
}
}else {
## Ask the requestor for an authentification
$key=substr(MD5->hexhash(join('/', $list->get_cookie(), $name,
$sender, $d1, $d2, 'expire', time)), -8);
push @msg::report, sprintf Msg(6, 48, $msg::expire_need_auth), $name,
$d1, $Conf{'sympa'},$key,$name, $d1, $d2;
@@ -1769,5 +1769,5 @@
print OUT "end";
close (OUT);
- do_log('info', 'EXPIRE %s %d %d from %s authentified (%d seconds)',
$name, $d1, $d2,
+ do_log('info', 'EXPIRE %s %d %d from %s auth requested (%d seconds)',
$name, $d1, $d2,
$sender, time-$time_command);
return 1;
@@ -1752,5 +1752,5 @@
}
}else {
- ## Ask the requestor for an authentification
+ ## Ask the requestor for an authentication
$key=substr(MD5->hexhash(join('/', $list->get_cookie(), $name,
$sender, $d1, $d2, 'expire', time)), -8);

--
Chip Salzenberg - a.k.a. - <address@concealed>
"I wanted to play hopscotch with the impenetrable mystery of existence,
but he stepped in a wormhole and had to go in early." // MST3K


  • [PATCH] "Authentificate" is not an English word...., Chip Salzenberg, 05/30/2000

Archive powered by MHonArc 2.6.19+.

Top of Page